@@ -15,8 +15,8 @@ class ValarConfig(AutoMigrationMixin, AutoUrlPatternsMixin, AppConfig):
         if os.environ.get('RUN_MAIN') == 'true':
             try:
                 from .dao.frame import MetaFrame
-                getattr(super(), 'set_url', None)()
-                getattr(super(), 'auto_migrate', None)()
+                # getattr(super(), 'set_url', None)()
+                # getattr(super(), 'auto_migrate', None)()
                 MetaFrame()
             except Exception as e:
                 traceback.print_exc()
