@@ -18,7 +18,11 @@ class ValarConsumer(AsyncJsonWebsocketConsumer):
 
     async def disconnect(self, code):
         await self.channel_layer.group_discard(VALAR_CHANNEL_GROUP, self.channel_name)
-        await self.close(code)
+        try:
+            await self.close(code)
+        except Exception as e:
+            print(e)
+            pass
 
     async def receive_json(self, data, *args, **kwargs):
         pass
