@@ -54,4 +54,7 @@ meta_field_key_defaults = {
     'valar.Menu': {
         'auth': ('pick', ['icon', 'path', 'name', 'roles', 'is_admin', 'scope']),
     },
+    'valar.Indicator': {
+        'default': ('pick', ['name', 'frequency', 'scope', 'unit', 'file']),
+    },
 }
