@@ -1,10 +1,10 @@
-import pymongo
 from django.apps import apps
 from django.conf import settings
 from urllib.parse import urlparse
 
 from django.core.mail import EmailMessage
 from minio import Minio
+from pymongo import MongoClient
 from pymongo.synchronous.collection import Collection
 
 from ..classes.singleton_meta import SingletonMeta
@@ -26,7 +26,7 @@ class ValarEngine(metaclass=SingletonMeta):
 
         # mon
         if hasattr(settings, 'MONGO_URI'):
-            self.mongo_client = pymongo.MongoClient(
+            self.mongo_client: MongoClient = MongoClient(
                 settings.MONGO_URI,
                 **{
                     'maxPoolSize': 10,
@@ -39,7 +39,7 @@ class ValarEngine(metaclass=SingletonMeta):
             )
             self.mongo_engine = self.mongo_client[settings.BASE_APP]
         else:
-            self.mongo_client = None
+            self.mongo_client: MongoClient = None
             self.mongo_engine = None
 
         # minio
