@@ -1,11 +1,12 @@
 from .channels.views import handel_channel
 from .views import rest, meta, file, auth, password
-from django.urls import path
+from django.urls import path, re_path
 
 urlpatterns = [
     path('socket/<str:handler>', handel_channel),
     path('batch', rest.batch),
     path('<str:db>/<str:entity>/save_one', rest.save_one),
+    path('<str:db>/<str:entity>/insert_one', rest.insert_one),
     path('<str:db>/<str:entity>/delete_one', rest.delete_one),
     path('<str:db>/<str:entity>/find_one', rest.find_one),
     path('<str:db>/<str:entity>/find', rest.find),
